
********************************************************************************
*                                                                              * 
*                    得失之祸：股市下跌对交通事故的溢出影响                    *
*                             Stata Version：Stata 17.0                        * 
*    
/*==================================================
                   相关变量说明
==================================================*/
/* claims.dta: 逐笔出险数据(用于描述性统计) 
age       					被保险人年龄
male      	      			被保险人性别,取1则男性,0则女性
price     	     			被保险车辆价格
*/

/* reg_data.dta: 主要回归分析数据

*交通事故数据 acc*
acc_allday					全天交通事故
acc_beforeopen				开盘前交通事故
acc_afteropen				开盘后交通事故
acc_time*					不同时段开盘后交通事故
acc_afteropen_male			男性开盘后交通事故
acc_afteropen_female		女性开盘后交通事故
acc_afteropen_age*			不同年龄开盘后交通事故
acc_afteropen_price*		不同车价开盘后交通事故
acc_afteropen_odds*	     	不同赔率开盘后交通事故

*收益率数据
retindex1					上证指数收益率（核心解释变量）
retindex300				    沪深300收益率
sd_retindex1			    经过去一年标准差调整的上证指数收益率

*气象数据（控制变量）
air_temperature 			气温
dew_point					露点温度
wind_speed					风速
precipitation				降雨量
precipitation_2				降雨量平方
air_quality					空气质量


*极端收益虚拟变量
extreme_neg_pct1			极端负收益（分位数法）
mild_neg_pct30				温和负收益（分位数法）
mild_pos_pct30				温和正收益（分位数法）
extreme_pos_pct1			极端正收益（分位数法）

extreme_neg_sd				极端负收益（均值方差法）
mild_neg_sd					温和负收益（均值方差法）
mild_pos_sd					温和正收益（均值方差法）
extreme_pos_sd				极端正收益（均值方差法）


jackpot						彩票奖池金额
reanum						股吧阅读量（股市注意力）
negpost					    股吧负面帖子占比（投资者负面情绪）

*/

/* reg_FIN.dta: 
acc_afteropen_fin			开盘后交通事故(按金融区/非金融区分区统计)
FIN							金融区虚拟变量
收益率和气象控制变量与reg_data一致
*/

/* reg_stockcar.dta: 
acc_afteropen_stockcar	    开盘后交通事故(按车辆-股市参与高/低分区统计)
stockcar					高股市参与车辆组虚拟变量
收益率和气象控制变量与reg_data一致
*/


/* reg_taxi.dta: 
acc_afteropen_stockcar	    开盘后出行订单量（按金融出行/非金融出行分区统计）
FIN							金融出行虚拟变量
收益率和气象控制变量与reg_data一致
*/



cd "E:\得失之祸"

log using "log\log.log", replace

* 控制变量：气温、露点温度、风速、降雨量、降雨量平方、空气质量
global control air_temperature   dew_point  wind_speed  precipitation precipitation_2   air_quality  

global outpath using output\table.rtf
global outpath2 using output\table_appendix.rtf		



*****************************结果报告*****************************

*--------------------------正文结果报告---------------------------
*-----------------------------------------------------------------

*-------------表1-描述性统计----------		
*--(1)车险特征
use data\claim,clear 
eststo :estpost sum age male price if year>=2012&year<=2016, listwise 
	esttab  $outpath ,replace label  ///  
		   title({\b 表1:} { 描述性统计（车险特征）}) ///  
		   cells((sum_w(       label(观测值))  ///  
				   mean(fmt(3) label(均值)) ///  
					 sd(fmt(3) label(标准差)) ///  
					min(fmt(3) label(最小值)) ///  
					max(fmt(3)label(最大值))))  ///  
			nomtitle nonumber noobs compress nogap
	
	est clear
					
*--(2)日度层面特征特征			
use data\reg_data,clear 
eststo :estpost sum acc_allday acc_beforeopen acc_afteropen     ///
			retindex1  air_temperature   dew_point  wind_speed  precipitation   air_quality  , listwise  
	
	esttab  $outpath ,append label ///
			   title({\b 表1:} { 描述性统计（日度层面特征）}) ///  
			   cells((sum_w(       label(观测值)) /// 
					   mean(fmt(3) label(均值)) /// 
						 sd(fmt(3) label(标准差)) /// 
						min(fmt(3) label(最小值)) /// 
						max(fmt(3)label(最大值)))) /// 
				nomtitle nonumber noobs compress nogap
		est clear
					
				
*-------------表2-基准回归----------	
use data\reg_data,clear 


eststo: reghdfe acc_allday  retindex1   $control    ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
	
eststo: reghdfe acc_beforeopen  retindex1  $control  ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
eststo: reghdfe acc_afteropen  retindex1  $control  ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
		
		
		esttab  $outpath , append label nogaps eqlabels(none) ///
				stats(Day_of_Week_FE Year_month_FE  N r2_a, fmt(%3s %3s %9.0f %9.3f)) ///
				indicate("控制变量=$control" ) drop(_cons) ///
				b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) ///
				title({\b 表2.} {基准回归})

					est clear

*-------------图1-细分时段回归系数图-----------	
use data\reg_data,clear 
eststo: reghdfe acc_time0930_1030  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_time1030_1130  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_time1130_1300  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_time1300_1400  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_time1400_1500  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_time1500_1700  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_time1700_1900  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_time1900_2100  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_time2100_2400  retindex1  $control ,abs(ym dow) vce(robust)



#delimit;
coefplot (est*,mcolor(black)  msize(big)  
			ciopts( recast(rcap) msize(med) lcolor(black))  	
			text(4.5 1.5 `"{fontface "微软雅黑":早市}"',size(10.5pt))
			text(4.5 3  `"{fontface "微软雅黑":午休}"',size(10.5pt))
			text(4.5 4.5 `"{fontface "微软雅黑":午市}"',size(10.5pt))
			text(4.5 7.5 `"{fontface "微软雅黑":收盘后}"',size(10.5pt))) ,
			aseq swapnames vertical  drop(_cons $control *dow) 
			ylabel(,labsize(medium) format(%3.0f)) 
		  	yline(0,lc(black*0.5) lp(dash) axis(1))
			xline(2.5, lc(black*0.8) lp(dot))  
			xline(3.5, lc(black*0.8) lp(dot))  
			xline(5.5, lc(black*0.8) lp(dot))  
			xlabel(1 "9:30-10:30" 2 "10:30-11:30" 3 "11:30-13:00" 4 "13:00-14:00" 5 "14:00-15:00"  
				6 "15:00-17:00" 7 "17:00-19:00" 8 "19:00-21:00" 9 "21:00-24:00",labsize(10pt) alternate)  
			xtitle(`"{fontface "仿宋":时段}"', height(6) size(medium))
			ytitle(`"{fontface "仿宋":参数估计}"', height(6) size(medium))
			legend(order(2 `"{fontface "仿宋":回归系数}"' 1 `"{fontface "仿宋":95%置信区间}"' ))
			graphregion(color(white))  name(time,replace)
;
#delimit cr		

	graph export output\图1_细分时段回归系数图.svg,replace as(svg) name(time)

			est clear
								
	
*-------------图2-极端收益效应-----------	
use data\reg_data,clear 

gen extreme_neg = extreme_neg_pct1
gen mild_neg = mild_neg_pct30
gen mild_pos = mild_pos_pct30
gen extreme_pos = extreme_pos_pct1
gen middle = extreme_neg==0&mild_neg==0&mild_pos==0&extreme_pos==0
eststo: reghdfe acc_afteropen extreme_neg   mild_neg o.middle mild_pos extreme_pos $control  ,abs(ym dow) vce(robust)
	
replace extreme_neg = extreme_neg_sd
replace mild_neg = mild_neg_sd
replace mild_pos = mild_pos_sd
replace extreme_pos = extreme_pos_sd 
replace middle = extreme_neg==0&mild_neg==0&mild_pos==0&extreme_pos==0
eststo: reghdfe acc_afteropen extreme_neg mild_neg o.middle    mild_pos extreme_pos $control  ,abs(ym dow) vce(robust)


#delimit;
coefplot
		(est1, label(`"{fontface "仿宋":分位数分类}"') offset(-0.05) mcolor(black) 
			msymbol(O) ciopts( recast(rcap) msize(med) lcolor(black)) )
		 (est2 , label(`"{fontface "仿宋":均值方差分类}"') offset(0.05) mcolor(black*0.5) 
			msymbol(Oh) ciopts( recast(rcap) msize(med) lcolor(black*0.5))) ///
		,omitted
		xtitle(`"{fontface "仿宋":股市收益率}"', height(6) size(medium))
		ytitle(`"{fontface "仿宋":参数估计}"', height(6) size(medium))
		ylabel(-3(1)4)
		xlabel(1 `"{fontface "仿宋":极端负收益}"' 2 `"{fontface "仿宋":温和负收益}"' 
				3 `"{fontface "仿宋":中间收益}"' 4 `"{fontface "仿宋":温和正收益}"'
				5 `"{fontface "仿宋":极端正收益}"' ,labsize(10pt) )  
		yline(0, lcolor(black*0.5) lp(dash))
		vertical  drop(_cons $control ) 
		legend(order(2  `"{fontface "仿宋":分位数分类}"' 1 `"{fontface "仿宋":95%置信区间}"' 
		4  `"{fontface "仿宋":均值标准差分类}"' 3 `"{fontface "仿宋":95%置信区间}"'  ) 
		row(2))
   		graphregion(color(white)) name(extreme,replace)
;
#delimit cr		

			est clear

graph export output\图2_极端收益效应.svg,replace as(svg) name(extreme)

					
					
*-------------表3-因果推断检验------------
use data/reg_fin,clear
eststo: reghdfe  acc_afteropen_fin  c.retindex1#c.FIN  FIN  retindex1  $control ,abs(ym dow)  vce(robust) 
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
		estadd local Date_FE "No",replace

eststo: reghdfe  acc_afteropen_fin  c.retindex1#c.FIN  FIN  ,abs(date)  vce(robust) 
		estadd local Day_of_Week_FE "No",replace
		estadd local Year_month_FE "No",replace
		estadd local Date_FE "Yes",replace
		
		esttab  $outpath ,append label nogaps eqlabels(none) ///
				stats(Day_of_Week_FE Year_month_FE Date_FE  N r2_a, fmt(%3s %3s  %3s  %3s %9.3f )) ///
				b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) ///
				indicate("控制变量=$control" ) drop(_cons) ///
				title({\b 表3.} {因果推断检验}) 
				est clear	
				
				
*-------------表4-机制检验：股市下跌、股市注意力和交通事故------------
use data/reg_data,clear
eststo:reghdfe readnum jackpot   $control    ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
eststo:reghdfe acc_afteropen   c.retindex1#c.jackpot  jackpot  retindex1  $control   ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
		
		esttab $outpath ,append label nogaps eqlabels(none) ///
				stats(Day_of_Week_FE Year_month_FE  N r2_a, fmt(%3s %3s %3s  %9.3f)) ///
				b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) ///
				indicate("控制变量=$control" ) drop(_cons) ///
				title({\b 表4.} {机制检验：股市下跌、股市注意力和交通事故})

				est clear

				
*-------------图3-异质性分析------------				
*（a） 性别
use data/reg_data,clear
eststo: reghdfe acc_afteropen_male  retindex1   $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_female  retindex1   $control ,abs(ym dow) vce(robust)
		
	#delimit;
	coefplot (est*,mcolor(black)  msize(big)  
				ciopts( recast(rcap) msize(med) lcolor(black)) ) ,
			  aseq swapnames vertical  drop(_cons $control *dow) 
			  ylabel(,labsize(medium) format(%3.0f)) 
			  yline(0,lwidth(vthin)  lpattern(dash) lcolor(black*0.8) )
			  xlabel(1  `"{fontface "仿宋":男性}"'   2 `"{fontface "仿宋":女性}"',labsize(medium)) 
			  xtitle(`"{fontface "仿宋":(a) 性别}"', height(6) size(medium))
			  ytitle(`"{fontface "仿宋":参数估计}"', height(6) size(medium))
			legend(order(2 `"{fontface "仿宋":回归系数}"' 1 `"{fontface "仿宋":95%置信区间}"' ) row(2))
		graphregion(color(white))  name(a, replace)
	;

	#delimit cr		
	est clear


*（b） 年龄
eststo: reghdfe acc_afteropen_age25  retindex1   $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_age25_35  retindex1   $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_age35_45  retindex1   $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_age45_55  retindex1   $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_age55_65  retindex1   $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_age65  retindex1   $control ,abs(ym dow) vce(robust)								
	
	#delimit;
	coefplot (est*,mcolor(black)  msize(big)  
				ciopts( recast(rcap) msize(med) lcolor(black)) ) ,
			  aseq swapnames vertical  drop(_cons $control *dow) 
			  ylabel(,labsize(medium) format(%3.0f)) 
			  yline(0,lwidth(vthin)  lpattern(dash) lcolor(black*0.8) )
			  xlabel(1 "<25"    2 "25-35"  3   "35-45"  4  "45-55"  5"55-65" 6">65" ,labsize(medium)) 
			  xtitle(`"{fontface "仿宋":(b) 年龄}"', height(6) size(medium))
			  ytitle(`"{fontface "仿宋":参数估计}"', height(6) size(medium))
			legend(order(2 `"{fontface "仿宋":回归系数}"' 1 `"{fontface "仿宋":95%置信区间}"' ) row(2))
		graphregion(color(white))  name(b, replace)
	;

	#delimit cr		
	est clear
				
*（c） 车价							
eststo: reghdfe acc_afteropen_price5  retindex1   $control ,abs(ym dow) vce(robust)								
eststo: reghdfe acc_afteropen_price5_10  retindex1   $control ,abs(ym dow) vce(robust)								
eststo: reghdfe acc_afteropen_price10_15  retindex1   $control ,abs(ym dow) vce(robust)								
eststo: reghdfe acc_afteropen_price15_20  retindex1   $control ,abs(ym dow) vce(robust)								
eststo: reghdfe acc_afteropen_price20_50  retindex1   $control ,abs(ym dow) vce(robust)								
eststo: reghdfe acc_afteropen_price50  retindex1   $control ,abs(ym dow) vce(robust)								

								
	#delimit;
	coefplot (est*,mcolor(black)  msize(big)  
				ciopts( recast(rcap) msize(med) lcolor(black)) ) ,
			  aseq swapnames vertical  drop(_cons $control *dow) 
			  ylabel(,labsize(medium) format(%3.0f)) 
			  yline(0,lwidth(vthin)  lpattern(dash) lcolor(black*0.8) )
			  xlabel(1  "<5"   2 "5-10" 3  "10-15"  4  "15-20"  5  "20-50"  6  ">50" ,labsize(medium)) 
			  xtitle(`"{fontface "仿宋":(c) 车价(单位：万元)}"', height(6) size(medium))
			  ytitle(`"{fontface "仿宋":参数估计}"', height(6) size(medium))
			  legend(order(2 `"{fontface "仿宋":回归系数}"' 1 `"{fontface "仿宋":95%置信区间}"' ) row(2))
		graphregion(color(white))  name(c, replace)
	;

	#delimit cr		
	est clear

	grc1leg  a b c, cols(2) imargin(0 0 0 0)   legendfrom(a)   position(4) ring(0)  ///
		plotregion(lcolor(white)) ///
		graphregion(lcolor(none) ilcolor(none) fcolor(white) margin(zero)) ///
		name(heter,replace)
		
		
	graph export output\图3_异质性检验.svg,replace as(svg) name(heter)
		est clear	
		


*--------------------------附录结果报告---------------------------
*-----------------------------------------------------------------		

*-------------附录Ⅰ 图Ⅰ1-样本代表性-----------	
*(a) 年份分布
import excel "样本代表性.xlsx", sheet("年份分布") firstrow clear
twoway  ( connected  样本数据 年份,msymbol(o) color(black))  ///
		(connected  上海市统计年鉴 年份,msymbol(o) color(black*0.5)) , ///
	    ytitle(`"{fontface 仿宋:事故比例}"') ///
		ylabel(0(0.05)0.35, format(%03.2f)) ///
		xtitle(`"{fontface 仿宋:年份}"')  ///
		legend(row(1) order(1 `"{fontface 仿宋:样本数据}"' 2 `"{fontface 仿宋:上海市统计年鉴}"')) ///
		name(a, replace)  scheme(tufte) 
		
	graph export output\附录Ⅰ图Ⅰa_年份分布.svg,replace as(svg) name(a)

*(b) 日内分布	
import excel "样本代表性.xlsx", sheet("日内分布") firstrow clear
twoway  ( connected  样本数据 小时,msymbol(o) color(black))  ///
		(connected  上海市道路风险地图 小时,msymbol(o) color(black*0.5)) , ///
		ytitle(`"{fontface 仿宋:事故比例}"') ///
		ylabel(0(0.05)0.15, format(%03.2f)) xlabel(0(1)23) ///
		xtitle(`"{fontface 仿宋:小时}"')  ///
		legend(row(1) order(1 `"{fontface 仿宋:样本数据}"' 2 `"{fontface 仿宋:上海市道路风险地图}"')) ///
		name(b, replace)  scheme(tufte) 	

	graph export output\附录Ⅰ图Ⅰb_日内分布.svg,replace as(svg) name(b)

	
*(c) 区域分布	
import excel "样本代表性.xlsx", sheet("区域分布") firstrow clear	
	cd  "E:\得失之祸\data\上海市地图\"
	spshape2dta  上海市.shp,replace 
	//将上海市地图shp文件转化为dta，包括上海市.dta 和上海市_shp.dta
	// Spatial-unit ID: _ID  Coordinates: _CY, _CX
merge 1:1  name using 上海市

grmap 样本数据 using 上海市_shp.dta , ///  
	id(_ID) osize(vvthin ...) ocolor(white ...) ///
	clmethod(custom ) clbreaks( 0  0.1  0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1 ) ///
	fcolor(blue*0.1 blue*0.2  blue*0.3 blue*0.4 blue*0.5 blue*0.6 blue*0.7 blue*0.8 blue*0.9 blue*1) ///
		graphr(margin(medium)) ///
	ti(`"{fontface 仿宋:样本数据}"')  ///
	label(data(上海市.dta) x(_CX) y(_CY) ///
	label(name) length(20) size(tiny) color(black)) legs(3)  legt(`"{fontface 仿宋:事故密度}"')        ///
	name(c1, replace)	
	  
grmap 上海市道路风险地图 using 上海市_shp.dta , ///
	id(_ID) osize(vvthin ...) ocolor(white ...) ///
	clmethod(custom ) clbreaks( 0  0.1  0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1 ) ///
	fcolor(blue*0.1 blue*0.2  blue*0.3 blue*0.4 blue*0.5 blue*0.6 blue*0.7 blue*0.8 blue*0.9 blue*1) ///
		graphr(margin(medium)) ///
	ti(`"{fontface 仿宋:上海市道路风险地图}"')  ///
	label(data(上海市.dta) x(_CX) y(_CY) ///
	label(name) length(20) size(tiny) color(black)) legs(3)  legt(`"{fontface 仿宋:事故密度}"')        ///
	name(c2, replace)

	grc1leg  c1 c2 , cols(2) imargin(0 0 0 0)   legendfrom(c1)   position(9) ring(1)  ///
			plotregion(lcolor(white)) ///
			graphregion(lcolor(none) ilcolor(none) fcolor(white) margin(zero)) ///
			name(c,replace)
			
cd  "E:\得失之祸"			
	graph export output\附录Ⅰ图Ⅰc_区域分布.svg,replace as(svg) name(c)


*-------------附录Ⅱ 表A1-提前滞后效应-----------	
use data\reg_data,clear 		
eststo: reghdfe acc_afteropen  retindex1 l.retindex1 f.retindex1 $control ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
eststo: reghdfe l.acc_afteropen retindex1  l.($control) ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace	
eststo: reghdfe f.acc_afteropen retindex1  f.($control) ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace

		esttab $outpath2,replace label nogaps eqlabels(none) ///
				stats(控制变量 Day_of_Week_FE Year_month_FE  N r2_a, fmt(%3s %3s %3s %9.3f %9.3f)) ///
				indicate( "常数项=_cons" ) ///
				keep(retindex1 F.retindex1 L.retindex1) ///
				b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) ///
				title({\b 附录Ⅱ 表A1.} {提前滞后效应})

				est clear

					
*-------------附录Ⅱ 表A2-投资者负面情绪-----------	
use data\reg_data,clear 		
eststo ols: reghdfe acc_afteropen  negpost $control ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
eststo iv:ivreghdfe  acc_afteropen  $control (negpost = retindex1) ,absorb(ym dow) first savefirst  savefprefix(first_)
		estadd scalar cdf1 =  `e(cdf)': iv
		estadd local Day_of_Week_FE "Yes": first_negpost
		estadd local Year_month_FE "Yes": first_negpost
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace

		esttab ols first_* iv  $outpath2, append label nogaps eqlabels(none) ///
				stats(Day_of_Week_FE Year_month_FE N cdf1  r2, fmt(%3s %3s %3s  %9.3f)) ///
				indicate( "控制变量= $control"  "常数项=_cons" ) ///
				b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) ///
				title({\b 附录Ⅱ 表A2.} {稳健性检验:投资者负面情绪})
					
				est clear

					

*-------------附录Ⅱ 表A3-替换解释变量与更改回归模型-----------	
use data\reg_data,clear 		
eststo: reghdfe acc_afteropen sd_retindex1 $control  ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
		
eststo: reghdfe acc_afteropen retindex300 $control  ,abs(ym dow) vce(robust)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
		
eststo : ppmlhdfe  acc_afteropen retindex1 $control ,abs(ym dow) d
		estadd local Year_month_FE "Yes",replace
		estadd local Day_of_Week_FE "Yes",replace
		margins,dydx(retindex1)
	
		esttab  $outpath2 , append label nogaps eqlabels(none) ///
				stats(Day_of_Week_FE Year_month_FE  N r2_a r2_p, fmt(%3s %3s %3s  %9.3f)) ///
				order(*ret*)	indicate("控制变量= $control"  "常数项=_cons" ) ///
				b(4) se(4)   star(* 0.10 ** 0.05 *** 0.01) ///
				title({\b 附录Ⅱ 表A3.} {稳健性检验:替换解释变量与更改回归模型})

				est clear
				
	
*--------------附录Ⅲ 表Ⅲ1做空机制的影响-----------	
use data\reg_data,clear 	
eststo e_short: reg acc_afteropen retshort  $control i.ym i.dow
eststo e_Nshort: reg acc_afteropen retNshort  $control i.ym i.dow
						
suest e_short e_Nshort					
test [e_short_mean]retshort = [e_Nshort_mean]retNshort 	
	
		estadd scalar pvalue= r(p):e_Nshort
		   
		esttab $outpath2, append label nogaps eqlabels(none) ///
				stats(  N r2_a pvalue, fmt(%3s %9.3f %9.3f)) ///
				indicate("控制变量=$control" "常数项=_cons" "Day_of_Week_FE = *dow*" "Year_month_FE = *ym*") ///
				b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) ///
				mtitle ("标的证券" "非标的证券") ///
				title({\b 附录Ⅲ 表Ⅲ1.} {做空机制的影响})
				est clear	
				

	
*-------------附录Ⅳ 表Ⅳ1-股市收益率与出行订单量-----------					
use data\reg_taxi,clear 
eststo : reghdfe order  c.FIN#c.retindex1 retindex1 FIN_taxi $control ,abs(dow week)
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Week_of_Month_FE "Yes",replace
		estadd local Date_FE "No",replace
eststo : reghdfe order    c.FIN#c.retindex1  FIN_taxi   ,abs(date)
		estadd local Day_of_Week_FE "No",replace
		estadd local Week_of_Month_FE "No",replace
		estadd local Date_FE "Yes",replace
		
		esttab $outpath2, append label nogaps eqlabels(none) ///
				stats(Day_of_Week_FE Week_of_Month_FE Date_FE  N r2_a, fmt(%3s %3s %3s %3s %9.3f)) ///
				indicate("控制变量=$control" ) drop(_cons) ///
				b(4) se(4)  star(* 0.10 ** 0.05 *** 0.01) ///
				title({\b 附录Ⅳ 表Ⅳ1.} {股市收益率与出行订单量})

				est clear			
	

				
*-------------附录Ⅴ 表Ⅴ1-因果推断检验:车辆-股市参与程度-----------					
				
use data/reg_stockcar,clear

eststo: reghdfe  acc_afteropen_car  c.retindex1#c.stock_car  stock_car  retindex1 $control ,abs(ym dow)  vce(robust) 
		estadd local Day_of_Week_FE "Yes",replace
		estadd local Year_month_FE "Yes",replace
		estadd local Date_FE "No",replace

eststo: reghdfe  acc_afteropen_car  c.retindex1#c.stock_car  stock_car  ,abs(date)  vce(robust) 
		estadd local Day_of_Week_FE "No",replace
		estadd local Year_month_FE "No",replace
		estadd local Date_FE "Yes",replace
		
		esttab  $outpath2 ,append label nogaps eqlabels(none) ///
				stats(Day_of_Week_FE Year_month_FE Date_FE  N r2_a, fmt(%3s %3s  %3s  %3s %9.3f )) ///
				b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) ///
				indicate("控制变量=$control" ) drop(_cons) ///
				title({\b 附录Ⅴ 表Ⅴ1.} {因果推断检验:车辆-股市参与程度}) 
				est clear	
				
								
	
				
*-------------附录Ⅵ 图Ⅵ1-股市收益率与不同赔付率（理赔额/保费）开盘后交通事故-----------	
use data\reg_data,clear 		
							
eststo: reghdfe acc_afteropen_odds10  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_odds10_50  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_odds50_100  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_odds100_200  retindex1  $control ,abs(ym dow) vce(robust)
eststo: reghdfe acc_afteropen_odds200  retindex1  $control ,abs(ym dow) vce(robust)


#delimit;
coefplot (est*,mcolor(black)  msize(big)  
			ciopts( recast(rcap) msize(med) lcolor(black)) ) ,
		  aseq swapnames vertical  drop(_cons $control *dow) 
		  ylabel(,labsize(medium) format(%3.0f)) 
		  yline(0,lwidth(vthin)  lpattern(dash) lcolor(black*0.8) )
		  xlabel(1 "<10%"    2 "10-50%"  3   "50-100%"  4  "100-200%"  5">200%" ,labsize(medium)) 
		  xtitle(`"{fontface "仿宋":理赔额/保费}"', height(8) size(medium))
		  ytitle(`"{fontface "仿宋":参数估计}"', height(6) size(medium))
		  legend(order(2 `"{fontface "仿宋":回归系数}"' 1 `"{fontface "仿宋":95%置信区间}"' ))
	graphregion(color(white))  name(odds,replace)
;
#delimit cr		
	graph export output\附录Ⅵ_图Ⅵ1_股市收益率与不同赔付率开盘后交通事故.svg,replace as(svg) name(odds)
	est clear

	
log close
